@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yaml
-version: 0.8.16
-id: yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-key: yaml_Gt3Jc9yFHAOFX97IB3ZFyz
+version: 0.8.17
+id: yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
+key: yaml_BbJTt2NWP8rHaPVn0MXFmr
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: stable
@@ -20,21 +20,21 @@ exposed-modules:
     Data.Yaml.Include
 hidden-modules: Data.Yaml.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.16
-library-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.16
-data-dir: /usr/share/arm-linux-ghc-7.10.3/yaml-0.8.16
-hs-libraries: HSyaml-0.8.16-Gt3Jc9yFHAOFX97IB3ZFyz
+import-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.17
+library-dirs: /usr/lib/ghc-7.10.3/site-local/yaml-0.8.17
+data-dir: /usr/share/arm-linux-ghc-7.10.3/yaml-0.8.17
+hs-libraries: HSyaml-0.8.17-BbJTt2NWP8rHaPVn0MXFmr
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    enclosed-exceptions-1.0.1.1-609f4f396c20c8289c1e73bde62fbdf4
+    enclosed-exceptions-1.0.1.1-178e95d86200c5f0616588d334587add
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
